import {callHandler, register} from "./jsbridge";
import {extend} from "./utils";

/**
 * 获取网络请求报文头
 * @param opt
 * @since v2.0.0
 */
export const getRequestHead = opt => {
	callHandler("getRequestHead", opt);
};

/**
 * 获取消息推送的ClientId
 * @param opt
 * @since v2.0.0
 */
export const getPushClientId = opt => {
	callHandler("getPushClientId", opt);
};

/**
 * 语音播报解密字符串用
 * @param opt
 * @since v2.0.0
 */
export const desDecryptMessage = opt => {
	callHandler("desDecryptMessage", opt);
};

/**
 * 获取消息推送数据
 * @param opt
 * @since v2.0.0
 */
export const requestMessageOrderByDate = opt => {
	let defaultSetting = {
		pageCount: 10
	};
	let setting = extend(defaultSetting, opt);
	callHandler("requestMessageOrderByDate", setting);
};

/**
 * 获取友盟消息推送设备令牌
 * @param opt
 * @since V1.0.0
 */
export const getUMDeviceToken = opt => {
	callHandler("getUMDeviceToken", opt);
};

/**
 * 配置语音输入的关键字
 * @param opt
 * @since V1.0.0
 * eg.
 * 	configVoiceKeyWords({
 * 		keywords: ['理财', "转账"]
 * 	})
 */
export const configVoiceKeywords = opt => {
	callHandler('configVoiceKeywords', opt)
};

/**
 * 注册监听接收语音输入的内容
 * @param fn
 * @since 1.0.0
 * @deprecated 已废弃
 * eg.
 * onReceiveVoiceInput(function(inputText){
 * 	 // inputText
 * })
 */
export const onReceiveVoiceInput = fn => {
	register('onReceiveVoiceInput', fn)
};

/**
 * 科大讯飞语音输入
 * @since 2.0.13
 * @param opt
 */
export const voiceInput = (opt = {}) => {
	if(!isNaN(parseInt(opt.timeout)) && opt.timeout>0){
		callHandler('voiceInput', opt)
	}else {
		opt.timeout = 30000
		callHandler('voiceInput', opt)
	}
}

/**
 *
 * @param {String} duriation 最长录音时间，单位为秒，缺省值为60秒
 * @param {Function} success 成功回调
 * @param {Function} fail 失败回调
 */
export const startRecord = (duriation, success, fail) => {
	// duriation 缺省
	if (typeof duriation === 'function') {
		fail = success
		success = duriation
		duriation = '60'
	}
	callHandler('startRecord', {
		duriation,
		success,
		fail
	})
}

/**
 * 结束录音
 * @param {Function} success 成功回调
 * @param {Function} fail 失败回调
 */
export const endRecord = (success, fail) => {
	callHandler('endRecord', {
		success,
		fail
	})
}
