import {isArray, isObject, isString} from "./utils";
import {callHandler, log} from "./jsbridge";

export const setSessionData = (object = {}) => {
	if (isObject(object.data)) {
		callHandler("setSessionData", object);
	} else {
		log("getSessionData 参数 data 为空");
	}
};

export const getSessionData = (object = {}) => {
	if (isArray(object.keyArray)) {
		callHandler("getSessionData", object);
	} else {
		log("getSessionData 参数 keyArray 不是数组，或数组为空！");
	}
};

export const clearSessionData = (opt) => {
	let keyArray = [];
	if(isString(opt)){
		keyArray.put(opt);
	}else if(isArray(opt)){
		keyArray = opt;
	}else if(isObject(opt)){
		if(isArray(opt.keyArray) && opt.keyArray.length){
			keyArray = opt.keyArray;
		}else {
			log("clearSessionData 参数 keyArray 不是数组，或数组为空！");
		}
	}else {
		log("clearSessionData 参数传入有误！");
	}
	callHandler("clearSessionData",{keyArray: keyArray});
};

export  const saveLocalData = (object = {}) => {
	if (isObject(object.data)) {
		callHandler("saveLocalData", object);
	} else {
		log("saveLocalData 参数 data 为空");
	}
};
export const getLocalData = (object) => {
	if (isArray(object.keyArray) && object.keyArray.length) {
		callHandler("getLocalData", object);
	} else {
		log("getLocalData 参数 keyArray 不是数组，或数组为空！");
	}
};

export const clearLocalData = (opt) => {
	let keyArray = [];
	if(isString(opt)){
		keyArray.put(opt);
	}else if(isArray(opt)){
		keyArray = opt;
	}else if(isObject(opt)){
		if(isArray(opt.keyArray) && opt.keyArray.length){
			keyArray = opt.keyArray;
		}else {
			log("clearLocalData 参数 keyArray 不是数组，或数组为空！");
		}
	}else {
		log("clearLocalData 参数传入有误！");
	}
	callHandler("clearLocalData",{keyArray:keyArray});
};

export const setHubData = opt => {
	if(!isObject(opt.data)){
		log("setHubData data参数不符合要求！");
		return false;
	}
	for (let key in opt.data){
		if(Object.prototype.hasOwnProperty.call(opt.data, key)){
			if(key.indexOf('@string') !== -1 || key.indexOf('@array') !== -1 || key.indexOf('@map') !== -1){
				if ( (key.indexOf('@string') !==-1 && !isString(opt.data[key]))){
					delete opt.data[key];
				}else if( (key.indexOf('@array') !==-1 && !isArray(opt.data[key])) ){
					delete opt.data[key];
				}else if( (key.indexOf('@map') !==-1 && !isObject(opt.data[key])) ){
					delete opt.data[key];
				}
			}else {
				delete opt.data[key];
			}

		}
	}
	callHandler('setHubData', opt);
};

export const getHubData = opt => {
	if (isArray(opt.keyArray) && opt.keyArray.length) {
		callHandler("getHubData", opt);
	} else {
		log("getHubData 参数 keyArray 不是数组，或数组为空！");
	}
};

export const getSynchronizeIds = (callback) => {
	getHubData({
		keyArray: ['synchronizeIds#array'],
		success: function (object) {
			setHubData({
				data: { 'synchronizeIds#array': []}
			});
			callback(object);
		}
	});
};
