import {extend, isArray, isBoolean} from "./utils";
import {callHandler} from "./jsbridge";
import {LOGIN_PASSWORD_REGEX} from "./const";

/**
 * 显示交易密码键盘
 * @param opt
 */
export const showTradeKeyboard = (opt) => {
    let defaultSetting = {
        title: '请输入交易密码',
        titleColor: '#000000',
        isRandom: true,
        html: '',
    };
    if (!isBoolean(opt.isRandom)) {//传入的参数不是boolean值，使用默认值
        opt.isRandom = true;
    }
    let setting = extend(defaultSetting, opt);
    let defaultHtml = "<!DOCTYPE html><html><head><meta charset='utf-8'><meta name='viewport' content='width=device-width, initial-scale=1, maximum-scale=1, minimum-scale=1'></head><body style=\'text-align:center;\'>@body</body></html>";
    if (!setting.html) {
        let contentTitle = '';
        let contentSubTitle = '';
        if (opt.contentTitle) {
            contentTitle = "<div style='display: inline;font-size: 18px;height: 25px;line-height: 25px;color: #666'>" + opt.contentTitle + "</div>";
        }
        if(opt.contentSubTitle){
            contentSubTitle = "<br><span style='font-size: 16px;color: #666'>"+opt.contentSubTitle.replace(/@start/g,"<span style='color: #333;font-size: 24px'>").replace(/@end/g,"</span>")+"</span>";
        }
        opt.html = contentTitle + contentSubTitle;
    }
    if(opt.html){
        opt.html = defaultHtml.replace('@body',opt.html);
    }
    callHandler('showTradeKeyboard',opt);
};

/**
 * 登录密码键盘
 * @param opt
 * @since v2.0.0
 */
export const showLoginKeyboard = opt => {
	callHandler("showLoginKeyboard", opt)
};

/**
 * 金额输入键盘
 * @param opt
 * @since v2.0.0
 */
export const showMoneyKeyboard = opt => {
	callHandler("showMoneyKeyboard", opt);
};

/**
 * 年利率键盘
 * @param opt
 * @since v2.0.0
 */
export const showRateKeyboard = opt => {
	callHandler("showRateKeyboard", opt);
};

/**
 * 显示手写签名板
 * @param opt
 * @since v2.0.0
 */
export const showSignPad = opt => {
	callHandler("showSignPad", opt);
};

/**
 * 获取登录密码
 * @param opt
 * @since v2.0.0
 */
export const getLoginPassword = opt => {
	let defaultSetting = {
		regex: LOGIN_PASSWORD_REGEX
	};
	let setting = extend(defaultSetting, opt);
	callHandler("getLoginPassword", setting);
};

/**
 * 清除登录密码缓存
 * @param opt
 * @since v2.0.0
 */
export const  clearLoginPassword = (opt = {}) => {
	callHandler("clearLoginPassword", opt);
};

/**
 * 获取密码安全等级
 * @param opt
 * @since v2.0.0
 */
export const getLoginPasswordSafeLevel = opt => {
	let defaultSetting = {
		regex: LOGIN_PASSWORD_REGEX
	};
	let setting = extend(defaultSetting, opt);
	callHandler("getLoginPasswordSafeLevel", setting);
};

/**
 * 比较2个密码是否一致
 * @param opt
 * @since v2.0.0
 */
export const compareLoginPassword = opt => {
	callHandler("compareLoginPassword", opt);
};



