import {callHandler, register, removeRegister} from "./jsbridge";

/**
 * 显示导航栏右侧按钮
 * @param opt
 * @since v2.0.0
 */
export const showOptionButton = opt => {
	callHandler("showOptionButton", opt);
};

/**
 * 显示导航栏右上角弹出的下拉菜单
 * @param opt
 * @since v2.0.0
 */
export const showOptionMenu = opt => {
	callHandler("showOptionMenu", opt);
};

/**
 * 隐藏导航栏右侧按钮和弹出菜单
 * @param opt
 * @since v2.0.0
 */
export const hideOptionButton = opt => {
	callHandler("hideOptionButton", opt);
};

/**
 * 设置导航栏标题
 * @param opt
 * @since v2.0.0
 */
export const setTitle = opt => {
	callHandler("setTitle", opt);
};

/**
 * 监听返回按钮事件
 * @param opt
 * @since v2.0.0
 */
export const onBackButtonAction = opt => {
	register("onBackButtonAction", opt.success);
	callHandler("onBackButtonAction", {});
};

/**
 * 移除返回按钮监听事件
 * @param opt
 * @since v2.0.0
 */
export const offBackButtonAction = opt => {
	removeRegister("offBackButtonAction");
	callHandler("offBackButtonAction", opt);
};

/**
 * 隐藏返回按钮
 * @param opt
 * @since V2.0.0
 */
export const hideBackButton = opt => {
	callHandler("hideBackButton", opt);
};

/**
 * 显示返回按钮
 * @param opt
 * @since v2.0.0
 */
export const showBackButton = opt => {
	callHandler("showBackButton", opt);
};

/**
 * 显示右侧按钮
 * @param {Object} opt
 * @since v2.0.40
 */
export const showTitleRightButton = opt => {
	callHandler("showTitleRightButton", opt);
}

/**
 * 隐藏右侧按钮
 * @param {Object} opt
 * @since v2.0.40
 */
export const hideTitleRightButton = opt => {
	callHandler("hideTitleRightButton", opt);
}

/**
 * 右侧按钮点击事件回调
 * @param {Function} fn
 * @since v2.0.40
 */
export const onTitleRightEventlistener = fn => {
	register("onTitleRightEventlistener", fn);
};

/**
 * 获取导航栏高度（标题栏+状态栏）
 * @param {Object} opt
 */
export const getNavigationBarHeight = opt => {
	callHandler("getNavigationBarHeight", opt);
}
