/**
 * 窗口行为
 * */

import { buildUrl, extend, isNumber, isObject, isString } from "./utils";
import {callHandler, log, register, removeRegister} from "./jsbridge";

export const pushWindow = (opt) => {
	if (opt.url && isString(opt.url)) {
		let paramDefault = {
			isFullScreen: true,
			animationType: "push",
			pullRefresh: false
		};
		opt.param = extend(paramDefault, opt.param);
		if (isObject(opt.data)) {
			opt.url = buildUrl(opt.url, opt.data);
			delete opt.data;
		}
		callHandler("pushWindow", opt);
	} else {
		log("sccbaJsAPI:pushWindow url is required");
	}
};

export const popWindow = (opt) => {
	callHandler("popWindow", opt);
};

export const popTo = (opt) => {
	let option = {};
	if (isNumber(opt.index) && opt.index < 0) {
		option.index = opt.index;
	} else if (isString(opt.urlPattern)) {
		option.urlPattern = opt.urlPattern;
	} else {
		log("[error]: 方法 popTo 参数 index 、 urlPattern 传入有误！");
		return;
	}
	if (!isObject(opt.data)) {
		option.data = {};
	}
	option.fail = opt.fail;
	callHandler("popTo", option);
};

export const redirectTo = (opt) => {
	if (opt.url && isString(opt.url)) {
		if (opt.url.indexOf("?") !== -1) {
			log("[warring]：redirectTo 如果要通过url传参数请使用data");
		}
		if (isObject(opt.data)) {
			opt.url = buildUrl(opt.url, opt.data);
			delete opt.data;
		}
		callHandler("redirectTo", opt);
	} else {
		log("[error]: method redirectTo url is required!");
	}
};

export const openInBrowser = (opt) => {
	if (isString(opt.url)) {
		callHandler("openInBrowser", opt);
	} else {
		log("[error]: method openInBrowser url is required!");
	}
};

export const openPullRefresh = function (opt) {
	if(opt.url){
		delete  opt.callback;
	}
	if(opt.callback){
		delete opt.url;
	}
	if(opt.url || opt.callback){
		callHandler("openPullRefresh",opt);
	}else {
		log("[error]: method openPullRefresh option url or callback is required!");
	}
};

export const onPageRefresh =  (fn) => {
	register("onPageRefresh",fn);
};

export const openInAppBrowser = opt => {
	if(!opt.animateType){
		opt.animateType = 'none';
	}
	callHandler('openInAppBrowser', opt);
};

export const onInAppBrowserLoadStart = fn => {
	register('onInAppBrowserLoadStart', fn);
};

export const onInAppBrowserLoadStop = fn => {
	register('onInAppBrowserLoadStop', fn);
};

export const onInAppBrowserLoadError = fn => {
	register('onInAppBrowserLoadError', fn);
};

export const onInAppBrowserExit = fn => {
	register('onInAppBrowserExit', fn);
};

export const closePullRefresh = () => {
	callHandler("closePullRefresh",{});
};

export const  onResume = (fn) => {
	register("onResume", fn);
};

export const onPause = (fn) => {
	register("onPause", fn);
};

export const onPageResume = (fn) => {
	register("onPageResume", fn);
};

export const onPagePause = (fn) => {
	register("onPagePause", fn);
};

// 添加返回按钮点击事件
export const addBackEventListener = (fn) => {
	callHandler('addBackEventListener', {})
	register("onBackEventListener", fn);
}

// 还原历史记录返回
export const removeBackEventListener = () => {
	callHandler('removeBackEventListener')
	removeRegister('onBackEventListener')
}


